summaryrefslogtreecommitdiff
path: root/src/gallium/drivers/lima/lima_state.c
diff options
context:
space:
mode:
authorQiang Yu <yuq825@gmail.com>2020-02-10 16:25:11 +0800
committerMarge Bot <eric+marge@anholt.net>2020-02-17 02:54:15 +0000
commit6fc0890cd9cf53dc41fee070faf4570314fdcbc3 (patch)
treedfd2ad8488c335dd38421e0be6fbd47c6b881e70 /src/gallium/drivers/lima/lima_state.c
parent57d9a51d455900946f3eac18b8d1d77cb03b972c (diff)
downloadmesa-6fc0890cd9cf53dc41fee070faf4570314fdcbc3.tar.gz
lima: rename lima_submit to lima_job
Reviewed-by: Vasily Khoruzhick <anarsoul@gmail.com> Signed-off-by: Qiang Yu <yuq825@gmail.com> Tested-by: Marge Bot <https://gitlab.freedesktop.org/mesa/mesa/merge_requests/3755> Part-of: <https://gitlab.freedesktop.org/mesa/mesa/merge_requests/3755>
Diffstat (limited to 'src/gallium/drivers/lima/lima_state.c')
-rw-r--r--src/gallium/drivers/lima/lima_state.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gallium/drivers/lima/lima_state.c b/src/gallium/drivers/lima/lima_state.c
index 2b48a3a124c..727b200d6db 100644
--- a/src/gallium/drivers/lima/lima_state.c
+++ b/src/gallium/drivers/lima/lima_state.c
@@ -41,15 +41,15 @@ lima_set_framebuffer_state(struct pipe_context *pctx,
{
struct lima_context *ctx = lima_context(pctx);
- /* make sure there are always single submit in this context */
- if (lima_debug & LIMA_DEBUG_SINGLE_SUBMIT)
+ /* make sure there are always single job in this context */
+ if (lima_debug & LIMA_DEBUG_SINGLE_JOB)
lima_flush(ctx);
struct lima_context_framebuffer *fb = &ctx->framebuffer;
util_copy_framebuffer_state(&fb->base, framebuffer);
- ctx->submit = NULL;
+ ctx->job = NULL;
ctx->dirty |= LIMA_CONTEXT_DIRTY_FRAMEBUFFER;
}